ttyd

package
v0.0.0-...-3b57c73 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Instance

type Instance struct {
	SessionID  string
	SocketPath string
	Cmd        *exec.Cmd
	CreatedAt  time.Time
	Proxy      *httputil.ReverseProxy
}

Instance manages a single ttyd process bound to a Unix domain socket.

type Manager

type Manager struct {
	// contains filtered or unexported fields
}

Manager manages ttyd instances indexed by session ID.

func NewManager

func NewManager(sockDir string) (*Manager, error)

NewManager creates a ttyd session manager.

func (*Manager) Close

func (m *Manager) Close()

Close cleans up all active ttyd sessions and socket files.

func (*Manager) GetOrStart

func (m *Manager) GetOrStart(sessionID string, workingDir string) (*Instance, error)

GetOrStart returns an existing active ttyd instance or starts a new one.

Jump to